/*
Copyright (C) 2002 Milos Negovanovic

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/




package gui.dialogs;
public class DialogSettings extends javax.swing.JDialog {
	private gui.frames.PortageMaster pm;
	
	private javax.swing.JPanel panelAll, panelFS, panelLayout, panelCommands, panelButtons;
	private javax.swing.border.TitledBorder borderFS, borderLayout, borderEditor;
	private javax.swing.JRadioButton radioFSSmall, radioFSNormal, radioFSLarge;
	private javax.swing.ButtonGroup groupFS;
	private javax.swing.JTextField textEditorCommand, textBrowser;
	private javax.swing.JButton buttonSave, buttonCancel;
	private javax.swing.JCheckBox checkAll, checkLocal, checkInstalled;
	
	
	public DialogSettings(gui.frames.PortageMaster owner) {
		super(owner);
		pm = owner;
		setTitle("Settings");
		initComponents();
		readProperties();
	}
	
	
	private void initComponents() {
		panelAll = new javax.swing.JPanel();
		panelFS = new javax.swing.JPanel();
		panelLayout = new javax.swing.JPanel();
		panelCommands = new javax.swing.JPanel();
		panelButtons = new javax.swing.JPanel();
		borderFS = javax.swing.BorderFactory.createTitledBorder(" Text size ");
		borderLayout = javax.swing.BorderFactory.createTitledBorder(" Layout ");
		borderEditor = javax.swing.BorderFactory.createTitledBorder(" Editor && Browser ");
		radioFSSmall = new javax.swing.JRadioButton("Small");
		radioFSNormal = new javax.swing.JRadioButton("Normal");
		radioFSLarge = new javax.swing.JRadioButton("Large");
		checkAll = new javax.swing.JCheckBox("All");
		checkLocal = new javax.swing.JCheckBox("Local");
		checkInstalled = new javax.swing.JCheckBox("Installed");
		groupFS = new javax.swing.ButtonGroup();
		textEditorCommand = new javax.swing.JTextField();
		textBrowser = new javax.swing.JTextField();
		buttonSave = new javax.swing.JButton("Save");
		buttonCancel = new javax.swing.JButton("Cancel");
		
		
		buttonSave.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent e) {
				buttonSave_Clicked(e);
			}
		});
		
		
		buttonCancel.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent e) {
				buttonCancel_Clicked(e);
			}
		});
		
		
		groupFS.add(radioFSSmall);
		groupFS.add(radioFSNormal);
		groupFS.add(radioFSLarge);
		
		
		panelFS.add(radioFSSmall);
		panelFS.add(radioFSNormal);
		panelFS.add(radioFSLarge);
		panelFS.setLayout(new java.awt.GridLayout(0,1));
		panelFS.setBorder(borderFS);
		
		
		panelLayout.add(checkAll);
		panelLayout.add(checkLocal);
		panelLayout.add(checkInstalled);
		panelLayout.setLayout(new java.awt.GridLayout(0,1));
		panelLayout.setBorder(borderLayout);
		
		
		textEditorCommand.setPreferredSize(new java.awt.Dimension(150,25));
		panelCommands.setLayout(new java.awt.GridLayout(3,2));
		panelCommands.add(new javax.swing.JLabel("Editor: "));
		panelCommands.add(textEditorCommand);
		panelCommands.add(new javax.swing.JLabel("Browser: "));
		panelCommands.add(textBrowser);
		panelCommands.add(new javax.swing.JLabel(""));
		panelCommands.setBorder(borderEditor);
		
		
		panelAll.add(panelFS);
		panelAll.add(panelLayout);
		panelAll.add(panelCommands);
		
		
		panelAll.setLayout(new java.awt.GridLayout(2,2));
		panelAll.setPreferredSize(new java.awt.Dimension(500,200));
		panelAll.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(10, 10, 10, 10)));
		
		
		panelButtons.add(buttonSave);
		panelButtons.add(buttonCancel);
		
		
		getContentPane().add(panelAll, java.awt.BorderLayout.CENTER);
		getContentPane().add(panelButtons, java.awt.BorderLayout.SOUTH);
		setLocation(150,150);
		pack();
		buttonCancel.requestFocus();
		show();
	}
	
	
	private void buttonSave_Clicked(java.awt.event.ActionEvent e) {
		hide();
		writeProperties();
	}
	
	
	private void buttonCancel_Clicked(java.awt.event.ActionEvent e) {
		hide();
	}
	
	
	private void readProperties() {
		switch (pm.getGP().getFS()) {
			case 10:
				radioFSSmall.setSelected(true);
				break;
			case 14:
				radioFSNormal.setSelected(true);
				break;
			case 18:
				radioFSLarge.setSelected(true);
				break;
		}
		
		
		String lay = pm.getGP().getLayout();
		if (lay.indexOf("A") != -1)
			checkAll.setSelected(true);
		if (lay.indexOf("L") != -1)
			checkLocal.setSelected(true);
		if (lay.indexOf("I") != -1)
			checkInstalled.setSelected(true);
		
		
		textEditorCommand.setText(pm.getGP().getEditor());
		
		
		textBrowser.setText(pm.getGP().getBrowser());
	}
	
	
	private void writeProperties() {
		if (radioFSSmall.isSelected()) {
			pm.getGP().setFS(10);
		}
		else {
			if (radioFSNormal.isSelected()) {
				pm.getGP().setFS(14);
			}
			else {
				if (radioFSLarge.isSelected()) {
					pm.getGP().setFS(18);
				}
			}
		}
		
		
		String lay = "";
		if (checkAll.isSelected())
			lay = lay + "A";
		if (checkLocal.isSelected())
			lay = lay + "L";
		if (checkInstalled.isSelected())
			lay = lay + "I";
		pm.getGP().setLayout(lay);
		
		
		pm.getGP().setEditor(textEditorCommand.getText());
		
		
		pm.getGP().setBrowser(textBrowser.getText());
		
		
		pm.getGP().writeConf();
	}
}
