/*
Copyright (C) 2002-2003 Milos Negovanovic

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/




package gui.frames;
public class PortageMaster extends javax.swing.JFrame implements java.awt.event.MouseListener {
	//
	//properties
	//
	private logic.GeneralProperties GP;
	
	
	private String Version = "0.2.1";
	
	
	//
	//property manipulators
	//
	public logic.GeneralProperties getGP() {
		return GP;
	}
	
	
	public String getVersion() {
		return Version;
	}
	
	
	public gui.components.DisplayStatusPane getStatusPane() {
		return paneStatus;
	}
	
	
	public gui.views.FileSystemTreePanel getAllPackagesView() {
		return allPackagesView;
	}
	
	
	public gui.views.FileSystemTreePanel getInstalledPackagesView() {
		return installedPackagesView;
	}
	
	
	//get currently selected tab
	public java.awt.Component getSelectedTab() {
		return tabMain.getSelectedComponent();
	}
	
	
	//
	//Constructor
	//
	public PortageMaster() {
		GP = new logic.GeneralProperties(this);
		setTitle("portageMaster " + GP.getVersion());
		initComponents();
	}
	
	
	//
	//components
	//
	private gui.components.DisplayStatusPane paneStatus;
	private fsl.FileSystemModel installedPackagesModel, allPackagesModel, 
		localPackagesModel;
	private gui.views.FileSystemTreePanel allPackagesView, installedPackagesView, 
		localPackagesView;
	
	
	//
	//native java components
	//
	private javax.swing.JTabbedPane tabMain;
	
	
	//
	//menu
	//
	private gui.menus.MainMenu menuMain;
	
	
	//
	//toolbars
	//
	private gui.toolbars.MainToolBar toolbarMain;
	
	
	//
	//initialise visible and other components procedure
	//
	private void initComponents() {
		//
		//different components
		//
		tabMain = new javax.swing.JTabbedPane(javax.swing.JTabbedPane.TOP);
		paneStatus = new gui.components.DisplayStatusPane();
		
		
		//
		//menu
		//
		menuMain = new gui.menus.MainMenu(this);
		
		
		//
		//toolbar
		//
		toolbarMain = new gui.toolbars.MainToolBar(this);
		
		
		//
		//listeners
		//
		addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing( java.awt.event.WindowEvent e ) {
				System.exit( 0 );
			}
		});
		
		
		//
		//menu stuff
		//
		setJMenuBar(menuMain);
		
		
		//
		//different stuff...buttons..panels...etc
		//
		paneStatus.setRsyncStatus(false);
		paneStatus.setCurrentEmerges(0);
		
		
		allPackagesModel = new fsl.FileSystemModel("/usr/portage");
		
		String localebuildsdir = new logic.Helper().getPortDirOverlay();
		if (localebuildsdir.equals("not defined")) {
			/*Object[] options = {"OK"};
			int n = javax.swing.JOptionPane.showOptionDialog(null, 
			"'PORTDIR_OVERLAY' is not configured !!!",
			"Error",
			javax.swing.JOptionPane.OK_OPTION,
			javax.swing.JOptionPane.INFORMATION_MESSAGE,
			null,
			options,
			options[0]);*/
		}
		else {
			localPackagesModel = new fsl.FileSystemModel(localebuildsdir);
			GP.setPortdirOverlay(localebuildsdir);
		}
		
		installedPackagesModel = new fsl.FileSystemModel("/var/db/pkg");
		
		allPackagesView = new gui.views.FileSystemTreePanel(allPackagesModel);
		allPackagesView.getTree().addMouseListener(this);
		allPackagesView.getTree().setName("all");
		
		localPackagesView = new gui.views.FileSystemTreePanel(localPackagesModel);
		localPackagesView.getTree().addMouseListener(this);
		localPackagesView.getTree().setName("local");
		
		installedPackagesView = new gui.views.FileSystemTreePanel(installedPackagesModel);
		installedPackagesView.getTree().addMouseListener(this);
		installedPackagesView.getTree().setName("installed");
		
		
		getContentPane().setLayout(new java.awt.BorderLayout());
		getContentPane().add(toolbarMain, java.awt.BorderLayout.NORTH);
		getContentPane().add(tabMain,java.awt.BorderLayout.CENTER);
		getContentPane().add(paneStatus,java.awt.BorderLayout.SOUTH);
		refreshLayout();
		refreshFS();
		
		
		setLocation(100,100);
		pack();
		show();
	}
	
	
	//
	//MouseListener interface implementation
	//
	public void mouseClicked(java.awt.event.MouseEvent e) {
		if (e.getClickCount()==2) {
			try {
				if (e.getComponent().getName() == "all") {
					if (allPackagesView.getTree().getLastSelectedPathComponent().toString().endsWith(".ebuild")) {
						emergeRequested("all");
					}
				}
				else if (e.getComponent().getName() == "installed") {
					javax.swing.tree.TreePath[] x = installedPackagesView.getTree().getSelectionPaths();
					for (int i = 0; i < x.length; i++) {
						if (installedPackagesView.getTree().getLastSelectedPathComponent().toString().endsWith(".ebuild")) {
							unmergeRequested();
						}
					}
				}
				else if (e.getComponent().getName().equals("local")) {
					javax.swing.tree.TreePath[] x = localPackagesView.getTree().getSelectionPaths();
					for (int i = 0; i < x.length; i++) {
						if (localPackagesView.getTree().getLastSelectedPathComponent().toString().endsWith(".ebuild")) {
							emergeRequested("local");
						}
					}
				}
			}
			catch (java.lang.NullPointerException exception) {
			}
		}
	}
	
	
	public void mousePressed(java.awt.event.MouseEvent e) {
		if (e.isPopupTrigger()) {
			try {
				if (e.getComponent().getName().equals("all")) {
					javax.swing.tree.TreePath[] x = allPackagesView.getTree().getSelectionPaths();
					if (x.length != 1) {
						for (int i = 0; i < x.length; i++) {
							if (x[i].getLastPathComponent().toString().endsWith(".ebuild")) {
								gui.menus.TreePopup z = new gui.menus.TreePopup(this,"all-simple", x[i].getLastPathComponent().toString());
								z.show(e.getComponent(), e.getX(), e.getY());
								break;
							}
						}
					}
					else if (allPackagesView.getTree().getLastSelectedPathComponent().toString().endsWith(".ebuild")) {
						gui.menus.TreePopup z = new gui.menus.TreePopup(this,"all", allPackagesView.getTree().getLastSelectedPathComponent().toString());
						z.show(e.getComponent(), e.getX(), e.getY());
					}
				}
				else if (e.getComponent().getName().equals("installed")) {
					javax.swing.tree.TreePath[] x = installedPackagesView.getTree().getSelectionPaths();
					if (x.length != 1) {
						for (int i = 0; i < x.length; i++) {
							if (x[i].getLastPathComponent().toString().endsWith(".ebuild")) {
								gui.menus.TreePopup z = new gui.menus.TreePopup(this,"installed-simple", x[i].getLastPathComponent().toString());
								z.show(e.getComponent(), e.getX(), e.getY());
								break;
							}
						}
					}
					else if (x[0].getLastPathComponent().toString().endsWith(".ebuild")) {
						gui.menus.TreePopup z = new gui.menus.TreePopup(this,"installed", x[0].getLastPathComponent().toString());
						z.show(e.getComponent(), e.getX(), e.getY());
					}
				}
				else if (e.getComponent().getName().equals("local")) {
					javax.swing.tree.TreePath[] x = localPackagesView.getTree().getSelectionPaths();
					if (x.length != 1) {
						for (int i = 0; i < x.length; i++) {
							if (x[i].getLastPathComponent().toString().endsWith(".ebuild")) {
								gui.menus.TreePopup z = new gui.menus.TreePopup(this,"local-simple", x[i].getLastPathComponent().toString());
								z.show(e.getComponent(), e.getX(), e.getY());
								break;
							}
						}
					}
					else if (localPackagesView.getTree().getLastSelectedPathComponent().toString().endsWith(".ebuild")) {
						gui.menus.TreePopup z = new gui.menus.TreePopup(this,"local", localPackagesView.getTree().getLastSelectedPathComponent().toString());
						z.show(e.getComponent(), e.getX(), e.getY());
					}
					
				}
			}
			catch (java.lang.NullPointerException exception) {
			}
		}
	}
	
	
	public void mouseReleased(java.awt.event.MouseEvent e) {
	}
	
	
	public void mouseEntered(java.awt.event.MouseEvent e) {
	}
	
	
	public void mouseExited(java.awt.event.MouseEvent e) {
	}
	
	
	//
	// RefreshFS is called after change has been made to font size in JTree
	// RefreshLayout when Layout changes
	//
	public void refreshFS() {
		allPackagesView.getTree().setFont(new java.awt.Font("Dialog",0,GP.getFS()));
		installedPackagesView.getTree().setFont(new java.awt.Font("Dialog",0,GP.getFS()));
		localPackagesView.getTree().setFont(new java.awt.Font("Dialog",0,GP.getFS()));
	}
	
	
	public void refreshLayout() {
		tabMain.remove(installedPackagesView);
		tabMain.remove(localPackagesView);
		tabMain.remove(allPackagesView);
		

		if ( GP.getLayout().indexOf("A") != -1 ) {
			tabMain.addTab("All", null, allPackagesView, "All ebuilds!!!");
		}
		if ( GP.getLayout().indexOf("L") != -1 ) {
			tabMain.addTab("Local", null, localPackagesView, "Local ebuilds!!!");
		}
		if ( GP.getLayout().indexOf("I") != -1 ) {
			tabMain.addTab("Installed", null, installedPackagesView, "Installed ebuilds!!!");
		}
		pack();
	}
	
	
	//
	// scans the "all" packages tree or "local" packages tree and
	// initiates "emerge" if valid nodes are selected
	//
	public void emergeRequested(String s) {
		boolean falsealarm = true;
		java.util.Vector toemerge = new java.util.Vector();
		javax.swing.tree.TreePath[] treePaths;
		
		
		treePaths = allPackagesView.getTree().getSelectionPaths();
		if (s.equals("local")) {
			treePaths = localPackagesView.getTree().getSelectionPaths();
		}
		
		
		if (treePaths != null) {
			for(int i=0;i<treePaths.length;i++) {
				if (treePaths[i].getLastPathComponent().toString().endsWith(".ebuild")) {
					falsealarm = false;
					toemerge.addElement(treePaths[i].getLastPathComponent());
				}
			}
		}
		
		if (!falsealarm) {
			logic.Ebuild z = new logic.Ebuild(this);
			z.setTreePaths(toemerge.elements());
			z.doEmerge();
		}
	}
	
	
	//
	// scans "installed" packages tree and initiates "unmerge" if
	// valid nodes are selected
	//
	public void unmergeRequested() {
		boolean falsealarm = true;
		java.util.Vector tounmerge = new java.util.Vector();
		java.util.Vector toupdate = new java.util.Vector();
		java.util.Vector toexpand = new java.util.Vector();
		java.util.Vector fullpaths = new java.util.Vector();
		java.util.Enumeration enumeration;
		javax.swing.tree.TreePath[] treePaths;
		
		
		java.util.Enumeration expanded = installedPackagesView.getTree().getExpandedDescendants(new javax.swing.tree.TreePath(installedPackagesView.getTree().getModel().getRoot()));
		treePaths = installedPackagesView.getTree().getSelectionPaths();
		
		
		if (treePaths != null) {
			for(int i=0;i<treePaths.length;i++) {
				if (treePaths[i].getLastPathComponent().toString().endsWith(".ebuild")) {
					falsealarm = false;
					tounmerge.addElement(treePaths[i].getLastPathComponent());
					toupdate.addElement(treePaths[i].getParentPath().getParentPath());
					fullpaths.addElement(treePaths[i]);
				}
			}
		}
		
		
		if (!falsealarm) {
			Object[] options = {"Yes","Cancel"};
			enumeration = tounmerge.elements();
			java.lang.StringBuffer packages = new java.lang.StringBuffer();
			while(enumeration.hasMoreElements()) {
				String s = enumeration.nextElement().toString();
				packages.append("Unmerge:   " + s.substring(s.lastIndexOf("/") + 1, s.length()) +"\n");
			}
			int n = javax.swing.JOptionPane.showOptionDialog(null,"\n" + packages.toString() + "\n\n" + "Procedee???",
				"Question",
				javax.swing.JOptionPane.YES_NO_OPTION,
				javax.swing.JOptionPane.QUESTION_MESSAGE,
				null,
				options,
				options[1]);
			if (n == 0) {
				enumeration = fullpaths.elements();
				
				
				while(expanded.hasMoreElements()) {
					javax.swing.tree.TreePath tp1 = (javax.swing.tree.TreePath)expanded.nextElement();
					enumeration = fullpaths.elements();
					while(enumeration.hasMoreElements()) {
						javax.swing.tree.TreePath tp2 = (javax.swing.tree.TreePath)enumeration.nextElement();
						if ( (tp1.equals(tp2)) || tp1.equals(tp2.getParentPath()) )  {
						}
						else {
							toexpand.addElement(tp1);
						}
					}
				}
				
				
				logic.Ebuild z = new logic.Ebuild(this);
				z.unmerge(tounmerge.elements(),toupdate.elements(),toexpand.elements());
			}
		}
	}
}
