/*
Copyright (C) 2002 Milos Negovanovic

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; withprint even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/




package logic;
public class GeneralProperties {
	private gui.frames.PortageMaster pm;
	
	private String Version;		// release version
	private int FS;			// 10,14 or 18 font size
	private String Layout;		// 0 is for split layprint, 1 for tabbed
	private String Editor;	// editor to be used for editing ebuilds
	private String Browser;		// internet browser
	private String PortdirOverlay;	// any local ebuilds?
	
	
	public GeneralProperties(gui.frames.PortageMaster x) {
		pm = x;
		PortdirOverlay = "";
		readConf();
	}
	
	
	public void setPortdirOverlay(String s) {
		PortdirOverlay = s;
	}
	public String getPortdirOverlay() {
		return PortdirOverlay;
	}
	
	
	public void setVersion(String NewVersion) {
		Version = NewVersion;
	}
	public String getVersion() {
		return Version;
	}
	
	
	public void setFS(int NewFS) {
		FS = NewFS;
		pm.refreshFS();
	}
	public int getFS() {
		return FS;
	}
	
	
	public void setLayout(String NewLayout) {
		Layout = NewLayout;
		pm.refreshLayout();
	}
	public String getLayout() {
		return Layout;
	}
	
	
	public void setEditor(String NewEditor) {
		Editor = NewEditor;
	}
	public String getEditor() {
		return Editor;
	}
	
	
	public void setBrowser(String NewBrowser) {
		Browser = NewBrowser;
	}
	public String getBrowser() {
		return Browser;
	}
	
	
	public void writeConf() {
		try {
			boolean success = (new java.io.File(System.getProperty("user.home") + "/.portagemaster")).mkdir();
			
			java.io.PrintWriter print = new java.io.PrintWriter(new java.io.FileWriter(new java.io.File(System.getProperty("user.home") + "/.portagemaster/conf"),false));
			print.println(Version);
			print.println(FS);
			print.println(Layout);
			print.println(Editor);
			print.println(Browser);
			print.close();
		}
		/*catch (java.io.FileNotFoundException e) {
			Object[] options = {"OK"};
			javax.swing.JOptionPane.showOptionDialog(null,
			"Configuration file not found !!! \n\n" 
			+ "You will have to create '/root/.portagemaster/' directory manualy.",
			"Error !!!",
			javax.swing.JOptionPane.OK_OPTION,
			javax.swing.JOptionPane.INFORMATION_MESSAGE,
			null,
			options,
			options[0]);
		}*/
		catch (java.io.IOException e) {
			Object[] options = {"OK"};
			javax.swing.JOptionPane.showOptionDialog(null,
			"Something's wrong with configuration file !!! \n\n" 
			+ "Defaults will be loaded.",
			"Error !!!",
			javax.swing.JOptionPane.OK_OPTION,
			javax.swing.JOptionPane.INFORMATION_MESSAGE,
			null,
			options,
			options[0]);
		}
	}
	
	
	public void readConf() {
		try {
			java.io.BufferedReader reader = new java.io.BufferedReader(new java.io.FileReader(new java.io.File(System.getProperty("user.home")+"/.portagemaster/conf")));
			
			
			Version = reader.readLine().trim();
			if ( Version.indexOf(pm.getVersion()) == -1 ) {
				Object[] options = {"OK"};
				javax.swing.JOptionPane.showOptionDialog(null,
					"Version mismatch !!!\n\n"
					+ "You must have upgraded portageMaster.\n\n"
					+ "Open settings page and click 'Save' in order to avoid this message next time.",
					"Error !!!",
					javax.swing.JOptionPane.OK_OPTION,
					javax.swing.JOptionPane.INFORMATION_MESSAGE,
					null,
					options,
					options[0]);
				Version = pm.getVersion();
			}
			
			
			FS = java.lang.Integer.parseInt(reader.readLine().trim());
			Layout = reader.readLine().trim();
			if (Layout.equals("0") || Layout.equals("1"))
				Layout = "ALI";
			Editor = reader.readLine().trim();
			Browser = reader.readLine().trim();
		}
		
		
		//
		//if there is no 'conf' file
		//
		catch (java.io.FileNotFoundException e) {
			Object[] options = {"OK"};
			javax.swing.JOptionPane.showOptionDialog(null,
			"Configuration file not found !!! \n\n"
			+ "This is the first time you are running portageMaster, or the conf file was deleted.\n\n"
			+ "Defaults will be loaded.",
			"Error !!!",
			javax.swing.JOptionPane.OK_OPTION,
			javax.swing.JOptionPane.INFORMATION_MESSAGE,
			null,
			options,
			options[0]);
			
			
			Version = pm.getVersion();
			FS = 14;
			Layout = "ALI";
			Editor = "xterm -e nano -w";
			Browser = "mozilla";
			writeConf();
		}
		
		
		//
		// if something goes wrong while reading 'conf' file
		//
		catch (java.io.IOException e) {
			Object[] options = {"OK"};
			javax.swing.JOptionPane.showOptionDialog(null,
			"Something's wrong with configuration file !!! \n\n" 
			+ "Defaults will be loaded.",
			"Error !!!",
			javax.swing.JOptionPane.OK_OPTION,
			javax.swing.JOptionPane.INFORMATION_MESSAGE,
			null,
			options,
			options[0]);
			
			
			Version = pm.getVersion();
			FS = 14;
			Layout = "ALI";
			Editor = "xterm -e nano -w";
			Browser = "mozilla";
			writeConf();
		}
		
		
		//
		//in case conf is empty write defaults
		//
		catch (java.lang.NullPointerException e) {
			Object[] options = {"OK"};
			javax.swing.JOptionPane.showOptionDialog(null,
			"Something's wrong with configuration file !!! \n\n" 
			+ "Defaults will be loaded.",
			"Error !!!",
			javax.swing.JOptionPane.OK_OPTION,
			javax.swing.JOptionPane.INFORMATION_MESSAGE,
			null,
			options,
			options[0]);
			
			Version = pm.getVersion();
			FS = 14;
			Layout = "ALI";
			Editor = "xterm -e nano -w";
			Browser = "mozilla";
			writeConf();
		}
	}
}
